@@ -21,8 +21,9 @@ from typing import NamedTuple
 import numpy as np
 from numpy import newaxis
 
-import gftool as gt
 from gftool import linalg
+from gftool.statistics import fermi_fct
+from gftool._util import _gu_sum
 
 
 polyvander = np.polynomial.polynomial.polyvander
@@ -185,6 +186,26 @@ class PoleGf(PoleFct):
         """
         return gf_tau(tau, poles=self.poles, weights=self.residues, beta=beta)
 
+    def eval_ret_t(self, tt):
+        """Evaluate the retarded time Green's function.
+
+        Parameters
+        ----------
+        tt : (...) float array_like
+            Green's function is evaluated at times `tt`, for `tt<0` it is 0.
+
+        Returns
+        -------
+        pole_gf_ret_t : (...) float np.ndarray
+            Retarded time Green's function.
+
+        See Also
+        --------
+        gf_ret_t
+
+        """
+        return gf_ret_t(tt, poles=self.poles, weights=self.residues)
+
     def occ(self, beta):
         """Calculate the occupation number.
 
@@ -199,7 +220,7 @@ class PoleGf(PoleFct):
             Occupation number.
 
         """
-        return np.sum(self.residues*gt.fermi_fct(self.poles, beta=beta), axis=-1)
+        return _gu_sum(self.residues*fermi_fct(self.poles, beta=beta))
 
     @classmethod
     def from_tau(cls, gf_tau, n_pole, beta, moments=(), occ=False, width=1., weight=None):
@@ -279,7 +300,10 @@ def gf_z(z, poles, weights):
     """
     poles = np.atleast_1d(poles)
     z = np.asanyarray(z)[..., newaxis]
-    return np.sum(weights/(z-poles), axis=-1)
+    return _gu_sum(weights / (z - poles))
+
+
+_gf_z = gf_z  # keep name, as gf_z is often locally overwritten
 
 
 def gf_d1_z(z, poles, weights):
@@ -306,15 +330,15 @@ def gf_d1_z(z, poles, weights):
     """
     poles = np.atleast_1d(poles)
     z = np.asanyarray(z)[..., newaxis]
-    return -np.sum(weights * (z - poles)**-2, axis=-1)
+    return -_gu_sum(weights * (z - poles)**-2)
 
 
 def _single_pole_gf_tau(tau, pole, beta):
     assert np.all((tau >= 0.) & (tau <= beta))
     # exp(-tau*pole)*f(-pole, beta) = exp((beta-tau)*pole)*f(pole, beta)
     exponent = np.where(pole.real >= 0, -tau, -tau + beta) * pole
-    # -(1-gt.fermi_fct(poles, beta=beta))*np.exp(-tau*poles)
-    return -np.exp(exponent) * gt.fermi_fct(-np.sign(pole.real)*pole, beta)
+    # -(1-fermi_fct(poles, beta=beta))*np.exp(-tau*poles)
+    return -np.exp(exponent) * fermi_fct(-np.sign(pole.real)*pole, beta)
 
 
 def gf_tau(tau, poles, weights, beta):
@@ -344,7 +368,36 @@ def gf_tau(tau, poles, weights, beta):
     poles = np.atleast_1d(poles)
     tau = np.asanyarray(tau)[..., newaxis]
     beta = np.asanyarray(beta)[..., newaxis]
-    return np.sum(weights*_single_pole_gf_tau(tau, poles, beta=beta), axis=-1)
+    return _gu_sum(weights*_single_pole_gf_tau(tau, poles, beta=beta))
+
+
+def _single_pole_gf_ret_t(tt, pole):
+    return np.where(tt >= 0, -1j*np.exp(-1j*pole*tt, where=(tt >= 0)), 0)
+
+
+def gf_ret_t(tt, poles, weights):
+    """Retarded time Green's function given by a finite number of `poles`.
+
+    Parameters
+    ----------
+    tt : (...) float array_like
+        Green's function is evaluated at times `tt`, for `tt<0` it is 0.
+    poles, weights : (..., N) float array_like or float
+        Position and weight of the poles.
+
+    Returns
+    -------
+    pole_gf_ret_t : (...) float np.ndarray
+        Retarded time Green's function.
+
+    See Also
+    --------
+    pole_gf_z : corresponding commutator Green's function
+
+    """
+    poles = np.atleast_1d(poles)
+    tt = np.asanyarray(tt)
+    return _gu_sum(weights*_single_pole_gf_ret_t(tt[..., newaxis], pole=poles))
 
 
 def moments(poles, weights, order):
@@ -369,7 +422,7 @@ def moments(poles, weights, order):
     """
     poles, weights = np.atleast_1d(*np.broadcast_arrays(poles, weights))
     order = np.asarray(order)[..., newaxis]
-    return np.sum(weights[..., newaxis, :] * poles[..., newaxis, :]**(order-1), axis=-1)
+    return _gu_sum(weights[..., newaxis, :] * poles[..., newaxis, :]**(order-1))
 
 
 def gf_from_moments(moments, width=1.) -> PoleFct:
@@ -491,7 +544,7 @@ def gf_from_z(z, gf_z, n_pole, moments=(), width=1., weight=None) -> PoleFct:
     poles = width * poles
     # z -> newaxis for poles, which are axis=-1
     # poles -> newaxis for sum over axis=-1, newaxis for z which should be axis=-2
-    gf_sp_mat = gt.pole_gf_z(z[..., newaxis], poles[..., newaxis, :, newaxis], weights=1)
+    gf_sp_mat = _gf_z(z[..., newaxis], poles[..., newaxis, :, newaxis], weights=1)
     gf_sp_mat = np.concatenate([gf_sp_mat.real, gf_sp_mat.imag], axis=-2)
     gf_z = np.concatenate([gf_z.real, gf_z.imag], axis=-1)
     otype = _get_otype(gf_z, moments, poles)
@@ -572,7 +625,7 @@ def gf_from_tau(gf_tau, n_pole, beta, moments=(), occ=False, width=1., weight=No
         constrain_mat = np.polynomial.polynomial.polyvander(poles, deg=moments.shape[-1]-1).T
         if occ:
             constrain_mat = np.concatenate(
-                np.broadcast_arrays(constrain_mat, gt.fermi_fct(poles, beta=beta)), axis=-2
+                np.broadcast_arrays(constrain_mat, fermi_fct(poles, beta=beta)), axis=-2
             )
             moments = np.concatenate(np.broadcast_arrays(moments, occ), axis=-1)
         _lstsq_ec = np.vectorize(linalg.lstsq_ec, signature='(m,n),(m),(l,n),(l)->(n)',
