@@ -175,6 +175,17 @@ class Lattice:
         for eps in np.linspace(lower - 1e-6, lower*1e4):
             assert self.lattice.dos(eps, **kwds) == 0
 
+    @given(z=st.complex_numbers(max_magnitude=1e6))
+    def test_hilbert_transform(self, z, kwds):
+        """Hilbert transform is same as non-interacting local Green's function.
+
+        Probably we should drop the Hilbert transform to avoid redundancy,
+        but as long as we have let's make sure it also is correct.
+        """
+        assume(abs(z.imag) > 1e-6)  # avoid singularities on real axis
+        assert (self.lattice.hilbert_transform(z, **kwds)
+                == pytest.approx(self.lattice.gf_z(z, **kwds)))
+
 
 class SymLattice(Lattice):
     """Generic class to test basic properties of symmetric `gftool.lattice` modules.
@@ -196,6 +207,12 @@ class SymLattice(Lattice):
             assert fp.quad(dos, [-D, 0.]) == pytest.approx(.5)
             assert fp.quad(dos, [0., +D]) == pytest.approx(.5)
 
+    @given(mm=st.integers(min_value=0))
+    def test_odd_dos_moments(self, mm, kwds):
+        """Odd moments vanish for even DOS."""
+        m_odd = 2*mm + 1
+        assert self.lattice.dos_moment(m_odd, **kwds) == 0.
+
 
 class TestBetheGf(GfProperties):
     """Check properties of Bethe Gf."""
@@ -645,6 +662,121 @@ class TestSimpleCubic(SymLattice):
         return [-half_bandwidth/3, half_bandwidth/3]
 
 
+class TestBodyCenteredCubicGf(GfProperties):
+    """Check properties of bcc Gf."""
+
+    D = 1.2
+    z_mesh = np.mgrid[-2*D:2*D:5j, -2*D:2*D:4j]
+    z_mesh = np.ravel(z_mesh[0] + 1j*z_mesh[1])
+
+    gf = method(gt.lattice.bcc.gf_z)
+
+    @staticmethod
+    @pytest.fixture(params=[0.7, 1.2, ])
+    def params(request):
+        """Parameters for simple cubic Green's function."""
+        return (), {'half_bandwidth': request.param}
+
+    @staticmethod
+    def band_edges(params):
+        """Return the support of the Green's function."""
+        D = params[1]['half_bandwidth']
+        return -D, D
+
+    def test_normalization(self, params, points=None):
+        """Singularities are needed for accurate integration."""
+        del points  # was only give for subclasses
+        super().test_normalization(params, points=[0])
+
+
+class TestBodyCenteredCubic(SymLattice):
+    """Check basic properties of `gftool.lattice.bcc`."""
+
+    lattice = gt.lattice.bcc
+
+    @staticmethod
+    @pytest.fixture(params=[0.5, 1., 2.], scope="class")
+    def kwds(request):
+        """Half-bandwidth of simple cubic lattice."""
+        return {"half_bandwidth": request.param}
+
+    @staticmethod
+    def band_edges(half_bandwidth):
+        """Return band-edges."""
+        return -half_bandwidth, half_bandwidth
+
+    @staticmethod
+    def singularities(half_bandwidth):
+        """Return singularities."""
+        del half_bandwidth
+        return [0]
+
+
+class TestFaceCenteredCubicGf(GfProperties):
+    """Check properties of fcc Gf."""
+
+    D = 1.2
+    z_mesh = np.mgrid[-2*D:2*D:5j, -2*D:2*D:4j]
+    z_mesh = np.ravel(z_mesh[0] + 1j*z_mesh[1])
+
+    gf = method(gt.lattice.fcc.gf_z)
+
+    @staticmethod
+    @pytest.fixture(params=[0.7, 1.2, ])
+    def params(request):
+        """Parameters for simple cubic Green's function."""
+        return (), {'half_bandwidth': request.param}
+
+    @staticmethod
+    def band_edges(params):
+        """Return the support of the Green's function."""
+        D = params[1]['half_bandwidth']
+        return -0.5*D, 1.5*D
+
+    def test_normalization(self, params, points=None):
+        """Singularities are needed for accurate integration."""
+        del points  # was only give for subclasses
+        super().test_normalization(params, points=[0])
+
+
+class TestFaceCenteredCubic(Lattice):
+    """Check basic properties of `gftool.lattice.fcc`."""
+
+    lattice = gt.lattice.fcc
+
+    @staticmethod
+    @pytest.fixture(params=[0.5, 1., 2.], scope="class")
+    def kwds(request):
+        """Half-bandwidth of simple cubic lattice."""
+        return {"half_bandwidth": request.param}
+
+    @staticmethod
+    def band_edges(half_bandwidth):
+        """Return band-edges."""
+        return -0.5*half_bandwidth, 1.5*half_bandwidth
+
+    @staticmethod
+    def singularities(half_bandwidth):
+        """Return singularities."""
+        del half_bandwidth
+        return [0]
+
+    def test_dos_moment(self, kwds):
+        """Moment is integral over ϵ^m DOS.
+
+        Overwritten to soften the absolute tolerance for ``m1`` which 0.
+        """
+        # check influence of bandwidth, as they are calculated for D=1 and normalized
+        dos = partial(self.lattice.dos, **kwds)
+        dos_moment = partial(self.lattice.dos_moment, **kwds)
+        left, right = self.band_edges(**kwds)
+        points = [left, *self.singularities(**kwds), right]
+        for mm in self.lattice.dos_moment_coefficients:
+            # pytint: disable=cell-var-from-loop
+            moment = fp.quad(lambda eps: eps**mm * dos(eps), points)
+            assert moment == pytest.approx(dos_moment(mm), rel=1e-6, abs=1e-10)
+
+
 class TestSurfaceGf(GfProperties):
     """Check properties of surface Gf."""
 
